Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(260)

Unified Diff: content/browser/renderer_host/resource_dispatcher_host_request_info.h

Issue 7058041: Remove ResourceDispatcherHost dependency on Chrome's LoginHandler and ExternalProtocolHandler. (Closed) Base URL: svn://chrome-svn/chrome/trunk/src/
Patch Set: fix deps Created 9 years, 7 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: content/browser/renderer_host/resource_dispatcher_host_request_info.h
===================================================================
--- content/browser/renderer_host/resource_dispatcher_host_request_info.h (revision 87739)
+++ content/browser/renderer_host/resource_dispatcher_host_request_info.h (working copy)
@@ -18,6 +18,7 @@
class CrossSiteResourceHandler;
class LoginHandler;
class ResourceDispatcherHost;
+class ResourceDispatcherHostLoginDelegate;
class ResourceHandler;
class SSLClientAuthHandler;
@@ -62,9 +63,11 @@
cross_site_handler_ = h;
}
- // Pointer to the login handler, or NULL if there is none for this request.
- LoginHandler* login_handler() const { return login_handler_.get(); }
- void set_login_handler(LoginHandler* lh);
+ // Pointer to the login delegate, or NULL if there is none for this request.
+ ResourceDispatcherHostLoginDelegate* login_delegate() const {
+ return login_delegate_.get();
+ }
+ void set_login_delegate(ResourceDispatcherHostLoginDelegate* ld);
// Pointer to the SSL auth, or NULL if there is none for this request.
SSLClientAuthHandler* ssl_client_auth_handler() const {
@@ -196,7 +199,7 @@
scoped_refptr<ResourceHandler> resource_handler_;
CrossSiteResourceHandler* cross_site_handler_; // Non-owning, may be NULL.
- scoped_refptr<LoginHandler> login_handler_;
+ scoped_refptr<ResourceDispatcherHostLoginDelegate> login_delegate_;
scoped_refptr<SSLClientAuthHandler> ssl_client_auth_handler_;
ChildProcessInfo::ProcessType process_type_;
int child_id_;

Powered by Google App Engine
This is Rietveld 408576698